@@ -1,15 +1,16 @@
 package Text::Table::More;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-09'; # DATE
-our $DIST = 'Text-Table-More'; # DIST
-our $VERSION = '0.016'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 #use utf8;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-27'; # DATE
+our $DIST = 'Text-Table-More'; # DIST
+our $VERSION = '0.017'; # VERSION
+
+# see Module::Features for more details on this
 our %FEATURES = (
     set_v => {
         TextTable => 1,
@@ -607,7 +608,7 @@ Text::Table::More - Generate text table with simple interface and many options
 
 =head1 VERSION
 
-This document describes version 0.016 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-09.
+This document describes version 0.017 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-27.
 
 =head1 SYNOPSIS
 
@@ -1100,14 +1101,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-Table
 
 Source repository is at L<https://github.com/perlancar/perl-Text-Table-More>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table-More>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Text::ANSITable> also offers lots of formatting options, but currently lacks
@@ -1127,6 +1120,23 @@ L<https://www.w3.org/html/wiki/Elements/table>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
@@ -1134,4 +1144,12 @@ This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table-More>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
